@@ -1,7 +1,8 @@
 #!/bin/sh
+export PATH='/usr/obj/hs-gio-0.12.5.3/bin:/usr/bin:/bin:/usr/sbin:/sbin:/usr/local/bin:/usr/local/bin:/usr/X11R6/bin'
 echo 'name: gio
-version: 0.12.4
-id: gio-0.12.4-a17738b9fa63112ce05f51d740ccb9ab
+version: 0.12.5.3
+id: gio-0.12.5.3-d5f59e6ced5a8c3a09541d2e6c7df575
 
 license: LGPL-2.1
 copyright: (c) 2001-2010 The Gtk2Hs Team
@@ -32,25 +33,25 @@ exposed-modules: System.GIO System.GIO.Enums System.GIO.Types
                  System.GIO.Volumes.Volume System.GIO.Volumes.VolumeMonitor
 hidden-modules: System.GIO.Signals
 trusted: False
-import-dirs: /usr/local/lib/ghc/gio-0.12.4
-library-dirs: /usr/local/lib/ghc/gio-0.12.4 /usr/local/lib
-hs-libraries: HSgio-0.12.4
+import-dirs: /usr/local/lib/ghc/gio-0.12.5.3
+library-dirs: /usr/local/lib/ghc/gio-0.12.5.3 /usr/local/lib
+hs-libraries: HSgio-0.12.5.3
 extra-libraries: gio-2.0 gobject-2.0 glib-2.0 intl
 extra-ghci-libraries:
 include-dirs: /usr/local/include/glib-2.0
               /usr/local/lib/glib-2.0/include /usr/local/include
 includes:
-depends: array-0.4.0.1-3b78425c10ff2dad7acf7e8c8ae014c3
-         base-4.6.0.1-6b06c3defb20732cfd08deb8ba52ca7c
-         bytestring-0.10.0.2-1c6ab0cabcb254a0e55d751d8ef17b51
-         containers-0.5.0.0-ab1dae9a94cd3cc84e7b2805636ebfa2
-         glib-0.12.4-e3c24025d434894ff47dcfccf269abe4
-         mtl-2.1.2-94c72af955e94b8d7b2f359dadd0cb62
+depends: array-0.5.0.0-470385a50d2b78598af85cfe9d988e1b
+         base-4.7.0.2-e1c96ce41208f09c293083d78870d5a2
+         bytestring-0.10.4.0-84f2b632cefc94e5dfeafb660607fcbd
+         containers-0.5.5.1-d4bd887fb97aa3a46cbadc13709b7653
+         glib-0.12.5.4-d17f895d256b06ee8202922370af528b
+         mtl-2.1.3.1-96f1a7910a7553352339ed05fb61c269
 hugs-options:
 cc-options:
 ld-options:
 framework-dirs:
 frameworks:
-haddock-interfaces: /usr/local/share/doc/hs-gio-0.12.4/html/gio.haddock
-haddock-html: /usr/local/share/doc/hs-gio-0.12.4/html
+haddock-interfaces: /usr/local/share/doc/hs-gio-0.12.5.3/html/gio.haddock
+haddock-html: /usr/local/share/doc/hs-gio-0.12.5.3/html
 ' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
